@@ -1,5 +1,8 @@
+import pytest
+
 import qcodes as qc
 import qcodes.utils.installation_info as ii
+from qcodes.utils.deprecate import QCoDeSDeprecationWarning
 
 # The get_* functions from installation_info are hard to meaningfully test,
 # but we can at least test that they execute without errors
@@ -10,14 +13,16 @@ def test_get_qcodes_version():
 
 
 def test_get_qcodes_requirements():
-    reqs = ii.get_qcodes_requirements()
+    with pytest.warns(QCoDeSDeprecationWarning):
+        reqs = ii.get_qcodes_requirements()
 
     assert isinstance(reqs, list)
     assert len(reqs) > 0
 
 
 def test_get_qcodes_requirements_versions():
-    req_vs = ii.get_qcodes_requirements_versions()
+    with pytest.warns(QCoDeSDeprecationWarning):
+        req_vs = ii.get_qcodes_requirements_versions()
 
     assert isinstance(req_vs, dict)
     assert len(req_vs) > 0
